@@ -33,9 +33,10 @@
 #  define LIBKIPI_DEPRECATED_NO_EXPORT LIBKIPI_NO_EXPORT LIBKIPI_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define LIBKIPI_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef LIBKIPI_NO_DEPRECATED
+#    define LIBKIPI_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
